@@ -6,7 +6,7 @@ import click
 
 from spaceforge._version import get_version
 from spaceforge.generator import generate_command
-from spaceforge.runner import runner_command
+from spaceforge.runner import run_command
 
 
 @click.group()
@@ -21,7 +21,18 @@ def cli() -> None:
 
 # Add subcommands
 cli.add_command(generate_command)
-cli.add_command(runner_command)
+cli.add_command(run_command)
+
+# KLUDGE: Add a hidden "runner" alias to the "run" command for backward compatibility.
+# It could be removed in the next major version.
+runner_alias = click.Command(
+    callback=run_command.callback,
+    help=run_command.help,
+    hidden=True,
+    name="runner",
+    params=run_command.params,
+)
+cli.add_command(runner_alias)
 
 
 def main() -> None:
