@@ -4,6 +4,7 @@ YAML generator for Spacelift plugins.
 
 import importlib.util
 import os
+import textwrap
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union
 
 import yaml
@@ -137,7 +138,7 @@ class PluginGenerator:
 
         doc = getattr(self.plugin_class, "__doc__", "")
         if doc:
-            doc = doc.strip()
+            doc = textwrap.dedent(doc).strip()
 
         metadata = {
             "name_prefix": getattr(
@@ -198,9 +199,13 @@ class PluginGenerator:
 
     def _update_with_requirements(self, mounted_files: List[MountedFile]) -> None:
         """Update the plugin hooks if there is a requirements.txt"""
-        if os.path.exists("requirements.txt") and self.config is not None:
+        # Look for requirements.txt in the same directory as the plugin file
+        plugin_dir = os.path.dirname(self.plugin_path)
+        requirements_path = os.path.join(plugin_dir, "requirements.txt")
+
+        if os.path.exists(requirements_path) and self.config is not None:
             # read the requirements.txt file
-            with open("requirements.txt", "r") as f:
+            with open(requirements_path, "r") as f:
                 mounted_files.append(
                     MountedFile(
                         path=f"{self.plugin_working_directory}/requirements.txt",
@@ -412,7 +417,8 @@ class PluginGenerator:
             def represent_str(self, data: str) -> Any:
                 """Override string representation for multiline strings."""
                 if data.count("\n") > 0:
-                    data = data.strip()
+                    # Use dedent to remove common leading whitespace from all lines
+                    data = textwrap.dedent(data).strip()
                     data = "\n".join([line.rstrip() for line in data.splitlines()])
                     return self.represent_scalar(
                         "tag:yaml.org,2002:str", data, style="|"
