@@ -88,7 +88,6 @@ class PluginExample(SpaceforgePlugin):
 
 
 class TestPluginGenerator:
-
     def setup_method(self) -> None:
         """Setup test fixtures."""
         self.temp_dir = tempfile.mkdtemp()
@@ -415,14 +414,14 @@ class NotAPlugin:
     def test_get_plugin_contexts_with_requirements(self, mock_exists: Mock) -> None:
         """Test context generation with requirements.txt."""
         mock_exists.side_effect = (
-            lambda path: path == "requirements.txt" or "plugin.py" in path
+            lambda path: path.endswith("requirements.txt") or "plugin.py" in path
         )
 
         # Mock specific file contents with a custom open function
         original_open = open
 
         def mock_open_func(filename: str, *args: Any, **kwargs: Any) -> Any:
-            if filename == "requirements.txt":
+            if filename.endswith("requirements.txt"):
                 from io import StringIO
 
                 return StringIO("requirements content")
@@ -534,7 +533,7 @@ class NotAPlugin:
                 after_plan_script = mf
                 break
         assert after_plan_script is not None
-        assert "spaceforge runner" in after_plan_script.content
+        assert "spaceforge run" in after_plan_script.content
         assert "after_plan" in after_plan_script.content
 
     def test_generate_manifest(self) -> None:
